@@ -24,7 +24,7 @@ from typing import (
     Any,
 )
 from logging.handlers import DatagramHandler
-from websocket_server import WebsocketServer
+from websocket_server import WebsocketServer #type: ignore
 from py2cfg.builder import CFGBuilder
 from py2cfg._source_db import CFG_Database
 
@@ -37,13 +37,6 @@ _pid: int
 # Stores pid of fork
 _child_pid: int
 
-# Database of module sources
-_modules: dict
-
-# Store lines executed by child
-_queue: multiprocessing.Queue
-
-
 LineCache = DefaultDict[
     Tuple[str, str, int], # filename, funcname, stacklevel
     List[int],            # list of executed lines
@@ -350,11 +343,6 @@ class QueueMGR:
     def close(self) -> None:
         self._rx.close()
         self._running = False
-    
-
-    def clear(self) -> None:
-        with self._lock:  
-            pass
 
 
 class ProcessFactory:
@@ -599,7 +587,6 @@ def wrap_user_line(func, entry):
                         )
                         logger.debug(f"Created at {src}")
                     return func(dbg, _frame)
-                 
 
                 elif _process_stack.curr_stack_level == frame.stack_level:
                     assert _process_stack[0].pid > 0
@@ -616,8 +603,6 @@ def wrap_user_line(func, entry):
                     _process_stack[0].terminate()
                     del _process_stack[0]
 
-
-
             if (k := (frame.filename, frame.lineno)) in cfg_db.at_lineno:
                 # When stopped at a functionDef statement, generate a 
                 # cfg with normal styling
