@@ -5,7 +5,7 @@ Control flow graph builder.
 """
 
 from collections import defaultdict, deque
-from typing import Dict, List, Optional, DefaultDict, Deque, Tuple, Union
+from typing import Dict, List, Optional, DefaultDict, Deque, Set, Union
 import ast  # type: ignore
 import enum
 from _ast import (
@@ -166,7 +166,7 @@ class CFGBuilder(ast.NodeVisitor):
         self.cfg.entryblock = self.current_block
         # Actual building of the CFG is done here.
         self.visit(tree)
-        self.clean_cfg(self.cfg.entryblock)
+        self.clean_cfg(self.cfg.entryblock, set())
         return self.cfg
 
     def build_from_src(self, name: str, src: str) -> CFG:
@@ -179,9 +179,12 @@ class CFGBuilder(ast.NodeVisitor):
 
         Returns:
             The CFG produced from the source code.
-        """
+        """ 
         tree = ast.parse(src, mode="exec")
-        return self.build(name, tree)
+        cfg = self.build(name, tree)
+        cfg.lineno = 1
+        cfg.end_lineno = len(src.splitlines())
+        return cfg
 
     def build_from_file(self, name: str, filepath: str) -> CFG:
         """
@@ -256,7 +259,7 @@ class CFGBuilder(ast.NodeVisitor):
             exitcase: An AST node representing the 'case' (or condition)
                       leading to the exit from the block in the program.
         """
-        newlink = Link(block, nextblock, exitcase)
+        newlink = Link(block, nextblock, exitcase)  # type: ignore
         block.exits.append(newlink)
         nextblock.predecessors.append(newlink)
 
@@ -295,9 +298,11 @@ class CFGBuilder(ast.NodeVisitor):
         # added to the class CFGs of the current CFG.
         class_body = ast.Module(body=node.body)
         class_builder = CFGBuilder(self.isShort, self._treebuf)
-        self.cfg.classcfgs[node.name] = class_builder.build(
+        self.cfg.classcfgs[node.name] = classcfg = class_builder.build(
             node.name, class_body, asynchr, self.current_id
         )
+        classcfg.lineno = node.lineno
+        classcfg.end_lineno = node.end_lineno # type: ignore
         self.current_id = class_builder.current_id + 1
 
     def new_functionCFG(self, node: FunctionDef, asynchr: bool = False) -> None:
@@ -320,9 +325,9 @@ class CFGBuilder(ast.NodeVisitor):
         )
         self.current_id = func_builder.current_id + 1
         cfg.lineno = node.lineno
-        cfg.end_lineno = node.end_lineno
+        cfg.end_lineno = node.end_lineno  # type: ignore
 
-    def clean_cfg(self, block: Block, visited: List[Block] = []) -> None:
+    def clean_cfg(self, block: Block, visited: Set[Block]) -> None:
         """
         Remove the useless (empty) blocks from a CFG.
 
@@ -335,7 +340,7 @@ class CFGBuilder(ast.NodeVisitor):
         # Don't visit blocks twice.
         if block in visited:
             return
-        visited.append(block)
+        visited.add(block)
 
         # Empty blocks are removed from the CFG.
         if block.is_empty():
@@ -714,35 +719,38 @@ class CFGBuilder(ast.NodeVisitor):
             self.current_block = self.new_block()
             # If we encounter a raise statement during body iteration,
             # we can link the raise block to the appropriate exception block (if any).
-            try_block.except_blocks[
-                None if child.type is None else child.type.id
-            ] = self.current_block
+            try:
+                try_block.except_blocks[
+                    None if child.type is None else child.type.id  # type: ignore
+                ] = self.current_block
+            except:
+                try_block.except_blocks[None] = self.current_block
             self.visit(child)
 
         stackobj.iter_state = TryEnum.BODY
         self.current_block = try_block
-        for child in node.body:
-            self.visit(child)
+        for child1 in node.body:
+            self.visit(child1)
 
         if node.orelse:
             stackobj.iter_state = TryEnum.ELSE
             else_block = self.new_block()
             self.current_block.add_exit(else_block)
             self.current_block = else_block
-            for child in node.orelse:
-                self.visit(child)
+            for child2 in node.orelse:
+                self.visit(child2)
 
         self.current_block.add_exit(after_tryblock)
         self.current_block = after_tryblock
         if node.finalbody:
             stackobj.iter_state = TryEnum.FINAL
-            for child in node.finalbody:
-                if isinstance(child, ast.Raise):
+            for child3 in node.finalbody:
+                if isinstance(child3, ast.Raise):
                     top = self.try_stack.popleft()
-                    self.visit_Raise(child)
+                    self.visit_Raise(child3)
                     self.try_stack.appendleft(top)
                     break
-                self.visit(child)
+                self.visit(child3)
             else:
                 next_block = self.new_block()
                 self.current_block.add_exit(next_block)
