@@ -4,6 +4,7 @@
 Control flow graph for Python programs.
 """
 
+import collections
 from typing import Any, Deque, Tuple, List, Optional, Iterator, Set, Dict
 import ast  # type: ignore
 from _ast import Compare  # For type-hinting
@@ -53,6 +54,9 @@ class Block(object):
         self.highlight: bool = False
         # Debugger at this block
         self.outline: bool = False
+    
+    def __iter__(self):
+        return iter(self.statements)
 
     def __str__(self) -> str:
         if self.statements:
@@ -289,6 +293,7 @@ class CFG(object):
         self.isShort = short
         self.lineno: int = 0
         self.end_lineno: int = 0
+        self.qualname = ""
 
 
     def __str__(self) -> str:
@@ -595,6 +600,7 @@ class CFG(object):
         interactive=False,
         build_keys=True,
         build_own=False,
+        diffable=None
     ) -> str:
         """
         Build a visualisation of the CFG with graphviz and output it in a DOT
@@ -607,14 +613,21 @@ class CFG(object):
             show: A boolean indicating whether to automatically open the output
                   file after building the visualisation.
         """
-        if cleanup is None: # Not sure why I did this.
-            cleanup = bool(os.environ["PY2CFG_CLEANUP"])
-        
+
+        if diffable is not None:
+            with open(diffable, "w") as fp:
+                for block in self:
+                    print(
+                        f"{block.id} {type(block.statements[0]).__name__}",
+                        file=fp,
+                    )
+
         graph = self._build_visual(format, calls, interactive, build_own)
         if build_keys:
             graph.subgraph(self._build_key_subgraph(format))
         return graph.render(filepath, view=show, cleanup=cleanup, directory=directory)
 
+
     def __iter__(self) -> Iterator[Block]:
         """
         Generator that yields all the blocks in the current graph, then
@@ -706,8 +719,8 @@ class CFG(object):
         self.outlined_block.outline = False
         if (block := self.bsearch(lineno, lst)) is None:
             return -1
-        self.outlined_block = block
-        block.outline = True
+        self.outlined_block = block #type: ignore
+        block.outline = True #type: ignore
         return 0
 
 
@@ -718,9 +731,41 @@ class CFG(object):
         
         highlighted_blocks: List[Block] = []
         for line in list(lines):
-            if (block := self.bsearch(line, blocks)) is not None:
+            if (block := self.bsearch(line, blocks)) is not None: #type: ignore
                 block.highlight = True
                 highlighted_blocks.append(block)
             
         self.highlighted_blocks = highlighted_blocks
         return 0
+
+    def find_path(self, finalblock: Block) -> Deque[Link]:
+        if self.entryblock is None:
+            raise ValueError("entryblock cannot be none")
+        
+        assert finalblock in self.finalblocks
+        visited: Set[Block] = set()
+        path: Deque[Link] = collections.deque()
+        def _find_path(link: Link):
+            blk: Block = link.target
+            if blk in visited:
+                return False
+            
+            visited.add(blk)
+            if blk == finalblock:
+                return True
+            
+            for lk in blk.exits:
+                path.append(lk)
+                if _find_path(lk):
+                    return True
+                path.pop()
+
+        for lk in self.entryblock.exits:
+            path.append(lk)
+            if _find_path(lk):
+                return path
+            path.pop()
+        
+        # TODO find all possible paths from entry to final and return set
+        # TODO find path from any line to any line
+        return collections.deque()
\ No newline at end of file
